Krolib: Schedules for Humans
============================

[![image](https://img.shields.io/pypi/v/krolib.svg)](https://pypi.org/project/krolib/)
[![image](https://img.shields.io/pypi/l/krolib.svg)](https://pypi.org/project/krolib/)
[![image](https://img.shields.io/pypi/pyversions/krolib.svg)](https://pypi.org/project/krolib/)

DSL to handle complex schedules

Installation
------------

``` {.sourceCode .bash}
$ pip install krolib
```
